import { RollupOptions } from 'rollup';
import { PackageConfig } from '../model/package-config';
import { PackerConfig } from '../model/packer-config';
import logger from '../common/logger';
import { PackageModuleType } from '../model/package-module-type';
import { BabelConfig } from '../model/babel-config';
/**
 * Get distribution banner comment.
 * @param packerConfig Packer configuration object.
 * @param packageConfig Package configuration object.
 */
export declare const getBanner: (packerConfig: PackerConfig, packageConfig: PackageConfig) => Promise<string>;
/**
 * Get rollup base configuration.
 * @param packerConfig Packer configuration object.
 * @param packageConfig Package configuration object.
 * @param banner Banner comment.
 * @param sourceMap If true, a separate sourcemap file will be created. If inline, the sourcemap will be appended to
 * the resulting output file as a data URI.
 */
export declare const getBaseConfig: (packerConfig: PackerConfig, packageConfig: PackageConfig, banner: string, sourceMap?: boolean | "inline") => {
    input: string;
    output: {
        banner: string;
        name: string;
        sourcemap: boolean | "inline";
    };
};
/**
 * Get rollup style build plugins.
 * @param packerConfig Packer configuration object.
 * @param packageConfig Package configuration object.
 * @param watch Copy stylesheets artifacts to watch temp directory if true, else dist directory.
 * @param main Indicate whether it is the main build task to emit stylesheets. Otherwise, ignore style sheet building
 * unless style inline mode is enabled.
 * @param log Logger reference.
 */
export declare const getStyleBuildPlugins: (packerConfig: PackerConfig, packageConfig: PackageConfig, watch: boolean, main: boolean, log: logger) => import("rollup").Plugin[];
/**
 * Generate minified style sheets.
 * @param packerConfig Packer configuration object.
 * @param packageConfig Package configuration object.
 * @param log Logger reference.
 */
export declare const generateMinStyleSheet: (packerConfig: PackerConfig, packageConfig: PackageConfig, log: logger) => Promise<void>;
/**
 * Get rollup dependency resolve plugins.
 * @param packerConfig  Packer configuration object.
 */
export declare const getDependencyResolvePlugins: (packerConfig: PackerConfig) => import("rollup").Plugin[];
/**
 * Get script build rollup plugins.
 * @param packageModule Package module type.
 * @param generateDefinition Generate type definitions if true.
 * @param check Set to false to avoid doing any diagnostic checks on the code.
 * @param packerConfig Packer configuration object.
 * @param babelConfig Babel configuration object.
 * @param typescript Typescript compiler reference.
 * @param log  Logger reference.
 */
export declare const getScriptBuildPlugin: (packageModule: PackageModuleType, generateDefinition: boolean, check: boolean, packerConfig: PackerConfig, babelConfig: BabelConfig, typescript: any, log: logger) => any[];
/**
 * Get pre bundle rollup plugins.
 * @param packerConfig Packer configuration object.
 */
export declare const getPreBundlePlugins: (packerConfig: PackerConfig) => any[];
/**
 * Get post bundle rollup plugins.
 * @param task Gulp task name.
 * @param type Package module type.
 * @param packerConfig Packer config object.
 */
export declare const getPostBundlePlugins: (packerConfig: PackerConfig, task: string, type: PackageModuleType) => import("rollup").Plugin[];
/**
 * Get custom rollup plugins included via packer config.
 * @param packerConfig Packer configuration object.
 * @param type Package module type.
 */
export declare const customRollupPlugins: (packerConfig: PackerConfig, type: PackageModuleType) => any[];
/**
 * Generate bundled artifacts via rollup.
 * @param packerConfig Packer configuration object.
 * @param packageConfig Package configuration object.
 * @param bundleConfig Rollup bundle configuration object.
 * @param type Package module type.
 * @param minify Generate minified bundle artifact if true.
 * @param trackBuildPerformance Track rollup build performance.
 * @param log Logger reference.
 */
export declare const generateBundle: (packerConfig: PackerConfig, packageConfig: PackageConfig, bundleConfig: RollupOptions, type: PackageModuleType, minify: boolean, trackBuildPerformance: boolean, log: logger) => Promise<void>;
/**
 * Get external dependency filter function.
 * @param packerConfig Packer config object.
 */
export declare const getExternalFilter: (packerConfig: PackerConfig) => (id: string) => boolean;
/**
 * Extract bundle external.
 * @param packerConfig Packer config object.
 */
export declare const extractBundleExternals: (packerConfig: PackerConfig) => string[] | ((id: string) => boolean);
